Keen | Buttons Examples
Description: Buttons examples

# Customer Relationship Management

New Order

### Buttons Examples

Reports
A common UI paradigm to use with interactive tables is to present buttons that will trigger some action. See official documentation here.

### Export Tools

Order ID | Country | Ship City | Ship Address | Company Agent | Company Name | Status | Type
--- | --- | --- | --- | --- | --- | --- | ---
61715-075 | China | Tieba | 746 Pine View Junction | Nixie Sailor | Gleichner, Ziemann and Gutkowski | 3 | 2
63629-4697 | Indonesia | Cihaur | 01652 Fulton Trail | Emelita Giraldez | Rosenbaum-Reichel | 6 | 3
68084-123 | Argentina | Puerto Iguazú | 2 Pine View Park | Ula Luckin | Kulas, Cassin and Batz | 1 | 2
67457-428 | Indonesia | Talok | 3050 Buell Terrace | Evangeline Cure | Pfannerstill-Treutel | 1 | 3
31722-529 | Austria | Sankt Andrä-Höch | 3038 Trailsway Junction | Tierney St. Louis | Dicki-Kling | 2 | 3
64117-168 | China | Rongkou | 023 South Way | Gerhard Reinhard | Gleason, Kub and Marquardt | 5 | 3
43857-0331 | China | Baiguo | 56482 Fairfield Terrace | Englebert Shelley | Jenkins Inc | 2 | 3
64980-196 | Croatia | Vinica | 0 Elka Street | Hazlett Kite | Streich LLC | 6 | 1
0404-0360 | Colombia | San Carlos | 38099 Ilene Hill | Freida Morby | Haley, Schamberger and Durgan | 2 | 1
52125-267 | Thailand | Maha Sarakham | 8696 Barby Pass | Obed Helian | Labadie, Predovic and Hammes | 1 | 3
54092-515 | Brazil | Canguaretama | 32461 Ridgeway Alley | Sibyl Amy | Treutel-Ratke | 4 | 2
0185-0130 | China | Jiamachi | 23 Walton Pass | Norri Foldes | Strosin, Nitzsche and Wisozk | 3 | 1
21130-678 | China | Qiaole | 328 Glendale Hill | Myrna Orhtmann | Miller-Schiller | 3 | 1
40076-953 | Portugal | Burgau | 52550 Crownhardt Court | Sioux Kneath | Rice, Cole and Spinka | 4 | 1
36987-3005 | Portugal | Bacelo | 548 Morrow Terrace | Christa Jacmar | Brakus-Hansen | 1 | 2
67510-0062 | South Africa | Pongola | 02534 Hauk Trail | Shandee Goracci | Bergnaum, Thiel and Schuppe | 5 | 3
36987-2542 | Russia | Novokizhinginsk | 19427 Sloan Road | Jerrome Colvie | Kreiger, Glover and Connelly | 3 | 1
11673-479 | Brazil | Conceição das Alagoas | 191 Stone Corner Road | Michaelina Plenderleith | Legros-Gleichner | 1 | 2
47781-264 | Ukraine | Yasinya | 1481 Sauthoff Place | Lombard Luthwood | Haag LLC | 1 | 2
42291-712 | Indonesia | Kembang | 9029 Blackbird Point | Leonora Chevin | Mann LLC | 2 | 3
64679-154 | Mongolia | Sharga | 102 Holmberg Park | Tannie Seakes | Blanda Group | 6 | 3
49348-055 | China | Guxi | 45 Butterfield Street | Yardley Wetherell | Gerlach-Schultz | 2 | 2
47593-438 | Portugal | Viso | 97 Larry Center | Bryn Peascod | Larkin and Sons | 6 | 1
54569-0175 | Japan | Minato | 077 Hoffman Center | Chrissie Jeromson | Brakus-McCullough | 2 | 1
0093-1016 | Indonesia | Merdeka | 3150 Cherokee Center | Gusti Clamp | Stokes Group | 6 | 2
0093-5142 | China | Jianggao | 289 Badeau Alley | Otis Jobbins | Ruecker, Leffler and Abshire | 4 | 2
51523-026 | Germany | Erfurt | 132 Chive Way | Lonnie Haycox | Feest Group | 1 | 3
49035-522 | Australia | Eastern Suburbs Mc | 074 Algoma Drive | Heddi Castelli | Kessler and Sons | 5 | 1
58411-198 | Ethiopia | Kombolcha | 91066 Amoth Court | Tuck O'Dowgaine | Simonis, Rowe and Davis | 1 | 1
27495-006 | Portugal | Arrifes | 3 Fairfield Junction | Vernon Cosham | Kreiger-Nicolas | 4 | 2
55154-8284 | Philippines | Talisay | 09 Sachtjen Junction | Bryna MacCracken | Hyatt-Witting | 2 | 1
62678-207 | Libya | Zuwārah | 82 Thackeray Pass | Freda Arnall | Dicki, Morar and Stiedemann | 3 | 3
68428-725 | China | Zhangcun | 3 Goodland Terrace | Pavel Kringe | Goldner-Lehner | 4 | 1
0363-0724 | Morocco | Temara | 9550 Weeping Birch Crossing | Felix Nazaret | Waters, Quigley and Keeling | 5 | 3
37000-102 | Paraguay | Los Cedrales | 1 Ridge Oak Way | Penrod Allanby | Rodriguez Group | 2 | 3
55289-002 | Philippines | Dologon | 9 Vidon Terrace | Hubey Passby | Lemke-Hermiston | 2 | 3
15127-874 | Tanzania | Nanganga | 33 Anniversary Parkway | Magdaia Rotlauf | Hettinger, Medhurst and Heaney | 3 | 1
49349-123 | Indonesia | Pule | 77292 Bonner Plaza | Alfonse Lawrance | Schuppe-Harber | 1 | 3
17089-415 | Palestinian Territory | Za‘tarah | 42806 Ridgeview Terrace | Kessiah Chettoe | Mraz LLC | 5 | 2
51327-510 | Philippines | Esperanza | 4 Linden Court | Natka Fairbanks | Mueller-Greenholt | 3 | 3
Order ID | Country | Ship City | Ship Address | Company Agent | Company Name | Status | Type

### Dropdown Export Tools

Order ID | Country | Ship City | Ship Address | Company Agent | Company Name | Status | Type
--- | --- | --- | --- | --- | --- | --- | ---
61715-075 | China | Tieba | 746 Pine View Junction | Nixie Sailor | Gleichner, Ziemann and Gutkowski | 3 | 2
63629-4697 | Indonesia | Cihaur | 01652 Fulton Trail | Emelita Giraldez | Rosenbaum-Reichel | 6 | 3
68084-123 | Argentina | Puerto Iguazú | 2 Pine View Park | Ula Luckin | Kulas, Cassin and Batz | 1 | 2
67457-428 | Indonesia | Talok | 3050 Buell Terrace | Evangeline Cure | Pfannerstill-Treutel | 1 | 3
31722-529 | Austria | Sankt Andrä-Höch | 3038 Trailsway Junction | Tierney St. Louis | Dicki-Kling | 2 | 3
64117-168 | China | Rongkou | 023 South Way | Gerhard Reinhard | Gleason, Kub and Marquardt | 5 | 3
43857-0331 | China | Baiguo | 56482 Fairfield Terrace | Englebert Shelley | Jenkins Inc | 2 | 3
64980-196 | Croatia | Vinica | 0 Elka Street | Hazlett Kite | Streich LLC | 6 | 1
0404-0360 | Colombia | San Carlos | 38099 Ilene Hill | Freida Morby | Haley, Schamberger and Durgan | 2 | 1
52125-267 | Thailand | Maha Sarakham | 8696 Barby Pass | Obed Helian | Labadie, Predovic and Hammes | 1 | 3
54092-515 | Brazil | Canguaretama | 32461 Ridgeway Alley | Sibyl Amy | Treutel-Ratke | 4 | 2
0185-0130 | China | Jiamachi | 23 Walton Pass | Norri Foldes | Strosin, Nitzsche and Wisozk | 3 | 1
21130-678 | China | Qiaole | 328 Glendale Hill | Myrna Orhtmann | Miller-Schiller | 3 | 1
40076-953 | Portugal | Burgau | 52550 Crownhardt Court | Sioux Kneath | Rice, Cole and Spinka | 4 | 1
36987-3005 | Portugal | Bacelo | 548 Morrow Terrace | Christa Jacmar | Brakus-Hansen | 1 | 2
67510-0062 | South Africa | Pongola | 02534 Hauk Trail | Shandee Goracci | Bergnaum, Thiel and Schuppe | 5 | 3
36987-2542 | Russia | Novokizhinginsk | 19427 Sloan Road | Jerrome Colvie | Kreiger, Glover and Connelly | 3 | 1
11673-479 | Brazil | Conceição das Alagoas | 191 Stone Corner Road | Michaelina Plenderleith | Legros-Gleichner | 1 | 2
47781-264 | Ukraine | Yasinya | 1481 Sauthoff Place | Lombard Luthwood | Haag LLC | 1 | 2
42291-712 | Indonesia | Kembang | 9029 Blackbird Point | Leonora Chevin | Mann LLC | 2 | 3
64679-154 | Mongolia | Sharga | 102 Holmberg Park | Tannie Seakes | Blanda Group | 6 | 3
49348-055 | China | Guxi | 45 Butterfield Street | Yardley Wetherell | Gerlach-Schultz | 2 | 2
47593-438 | Portugal | Viso | 97 Larry Center | Bryn Peascod | Larkin and Sons | 6 | 1
54569-0175 | Japan | Minato | 077 Hoffman Center | Chrissie Jeromson | Brakus-McCullough | 2 | 1
0093-1016 | Indonesia | Merdeka | 3150 Cherokee Center | Gusti Clamp | Stokes Group | 6 | 2
0093-5142 | China | Jianggao | 289 Badeau Alley | Otis Jobbins | Ruecker, Leffler and Abshire | 4 | 2
51523-026 | Germany | Erfurt | 132 Chive Way | Lonnie Haycox | Feest Group | 1 | 3
49035-522 | Australia | Eastern Suburbs Mc | 074 Algoma Drive | Heddi Castelli | Kessler and Sons | 5 | 1
58411-198 | Ethiopia | Kombolcha | 91066 Amoth Court | Tuck O'Dowgaine | Simonis, Rowe and Davis | 1 | 1
27495-006 | Portugal | Arrifes | 3 Fairfield Junction | Vernon Cosham | Kreiger-Nicolas | 4 | 2
55154-8284 | Philippines | Talisay | 09 Sachtjen Junction | Bryna MacCracken | Hyatt-Witting | 2 | 1
62678-207 | Libya | Zuwārah | 82 Thackeray Pass | Freda Arnall | Dicki, Morar and Stiedemann | 3 | 3
68428-725 | China | Zhangcun | 3 Goodland Terrace | Pavel Kringe | Goldner-Lehner | 4 | 1
0363-0724 | Morocco | Temara | 9550 Weeping Birch Crossing | Felix Nazaret | Waters, Quigley and Keeling | 5 | 3
37000-102 | Paraguay | Los Cedrales | 1 Ridge Oak Way | Penrod Allanby | Rodriguez Group | 2 | 3
55289-002 | Philippines | Dologon | 9 Vidon Terrace | Hubey Passby | Lemke-Hermiston | 2 | 3
15127-874 | Tanzania | Nanganga | 33 Anniversary Parkway | Magdaia Rotlauf | Hettinger, Medhurst and Heaney | 3 | 1
49349-123 | Indonesia | Pule | 77292 Bonner Plaza | Alfonse Lawrance | Schuppe-Harber | 1 | 3
17089-415 | Palestinian Territory | Za‘tarah | 42806 Ridgeview Terrace | Kessiah Chettoe | Mraz LLC | 5 | 2
51327-510 | Philippines | Esperanza | 4 Linden Court | Natka Fairbanks | Mueller-Greenholt | 3 | 3
Order ID | Country | Ship City | Ship Address | Company Agent | Company Name | Status | Type

### Quick Actions

Orders
Uploades
Products
Customers
Blog Posts
Settings
02:30 PM
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall
Yestardey
FlyMore design mock-ups been uploadet by designers Bob, Naomi, Richard
PSD, Sketch, AJ
Aug 13,2018
Meeting with Ken Digital Corp ot Unit14, 3 Edigor Buildings, George Street, Loondon
England, BA12FJ
Meeting, Customer
May 09, 2018
KeenThemes created new layout whith tens of new options for Keen Admin panel
HTML,CSS,VueJS
01:20 AM
New secyrity alert by Firewall & order to take aktion on User Preferences
Security, Fieewall

### Recent Bills

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Orders

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Latest Invoices

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### New Comments

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View

### Recent Posts

Lorem Ipsum is simply dummy text of the printing and typesetting simply dummy text of the printing industry.
Dismiss View
Notifications
Enable notifications:
Enable audit log:
Notify on new orders:
Orders
Enable order tracking:
Enable orders reports:
Allow order status auto update:
Customers
Enable customer singup:
Enable customers reporting:
Notifiy on new customer registration:

- Demos

### Select A Demo

Demo 1
Default RTL Version
Demo 2
Default RTL Version
Demo 3
Default RTL Version
Demo 4
Default RTL Version
Demo 5
Default RTL Version
Demo 6
Default RTL Version
Demo 7
Coming soon
Demo 8
Coming soon
Demo 9
Coming soon
Buy Keen Now!